@@ -131,7 +131,7 @@ CONTAINS
 
     job = ' '
     prefix = 'pwscf'
-    CALL get_env( 'ESPRESSO_TMPDIR', tmp_dir )
+    CALL get_environment_variable( 'ESPRESSO_TMPDIR', tmp_dir )
     IF ( TRIM( tmp_dir ) == ' ' ) tmp_dir = './scratch/'
     conv_threshold = 1e-14_dp
     q_gipaw = 0.01_dp
@@ -223,7 +223,7 @@ CONTAINS
     USE io_global,     ONLY : stdout
     IMPLICIT NONE
 
-    CALL flush_unit( stdout )
+    FLUSH( stdout )
   END SUBROUTINE gipaw_summary
 
 
@@ -234,7 +234,7 @@ CONTAINS
     USE io_global,        ONLY : stdout
     USE wvfct,            ONLY : nbnd, npwx
     USE ldaU,             ONLY : lda_plus_U, nwfcU
-    USE io_files,         ONLY : prefix, iunhub, iunwfc, iunigk, &
+    USE io_files,         ONLY : prefix, iunhub, iunwfc, &
                                  nwordwfcU, nwordwfc, seqopn
     USE noncollin_module, ONLY : npol
     USE buffers,          ONLY : open_buffer
@@ -256,10 +256,6 @@ CONTAINS
     IF ( lda_plus_u ) &
        CALL open_buffer( iunhub, 'hub', nwordwfcU, io_level, exst )
     !
-    ! ... iunigk contains the number of PW and the indices igk
-    ! ... 
-    CALL seqopn( iunigk, 'igk', 'UNFORMATTED', exst )
-    !
     RETURN
   END SUBROUTINE gipaw_openfil
   !-----------------------------------------------------------------------
